function [ sbioModels_number, fitting_value ] = jz_sbioEnsemCheckVars( sysbio_models, fitting_value )

sbioModels_number = length(fieldnames(sysbio_models));
if any(length(fieldnames(fitting_value)) ~= sbioModels_number)
    error('??? The size of fitting_value should be equal to the number of systems biology models.');
end

for t_m = 1:sbioModels_number
    m_configset = getconfigset(sysbio_models.(['m' num2str(t_m)]));
    if any( fitting_value.(['m' num2str(t_m)]).time_span < 0) || any( (m_configset.StopTime - fitting_value.(['m' num2str(t_m)]).time_span) < 0 )
        error(['??? fitting_value.m' num2str(t_m) '.time_span should >=0 and <= the StopTime of sysbio_models.m' num2str(t_m)]);
    end
    if size(fitting_value.(['m' num2str(t_m)]).target_species_value,1) ~= length(fitting_value.(['m' num2str(t_m)]).time_span)
        error(['??? The number of rows specified in fitting_value.m' num2str(t_m) '.time_span and the number of rows of fitting_value.m' num2str(t_m) '.target_species_value should be equal.']);
    end
    if length(fitting_value.(['m' num2str(t_m)]).target_species_name) ~= length( sbioselect(sysbio_models.(['m' num2str(t_m)]), 'type', 'species', 'name', fitting_value.(['m' num2str(t_m)]).target_species_name))
        error(['??? Some fitting_value.m' num2str(t_m) '.target_species_name could not be found in the sysbio_models.m' num2str(t_m)]);
    end
    if size(fitting_value.(['m' num2str(t_m)]).target_species_value,2) ~= length(fitting_value.(['m' num2str(t_m)]).target_species_name)
        error(['??? The number of columns in fitting_value.m' num2str(t_m) '.target_species_value must be the same as the length of the fitting_value.m' num2str(t_m) ...
            '.target_species_name. Please add {} to the target_species_name, e.g. fitting_value.m' num2str(t_m) '.target_species_name = {''protein_name''}.']);
    end
    if isempty(fitting_value.(['m' num2str(t_m)]).target_species_value_scale)
        fitting_value.(['m' num2str(t_m)]).target_species_value_scale = fitting_value.(['m' num2str(t_m)]).target_species_value;
        fitting_value.(['m' num2str(t_m)]).target_species_value_scale(fitting_value.(['m' num2str(t_m)]).target_species_value_scale < 1) = 1;
    elseif all(size(fitting_value.(['m' num2str(t_m)]).target_species_value_scale) == [1 1])
        if fitting_value.(['m' num2str(t_m)]).target_species_value_scale ~= 1;
            warning('MATLAB:paramAmbiguous', ['The fitting_value.m' num2str(t_m) '.target_species_value_scale will be reset to 1']);
            fitting_value.(['m' num2str(t_m)]).target_species_value_scale = 1;
        end
    elseif all( size(fitting_value.(['m' num2str(t_m)]).target_species_value_scale) == [1 length(fitting_value.(['m' num2str(t_m)]).target_species_name)] )
        fitting_value.(['m' num2str(t_m)]).target_species_value_scale = ones( length(fitting_value.(['m' num2str(t_m)]).time_span), 1) * fitting_value.(['m' num2str(t_m)]).target_species_value_scale;
    elseif all( size(fitting_value.(['m' num2str(t_m)]).target_species_value_scale) == [length(fitting_value.(['m' num2str(t_m)]).time_span) 1] )
        fitting_value.(['m' num2str(t_m)]).target_species_value_scale = fitting_value.(['m' num2str(t_m)]).target_species_value_scale * ones( 1, length(fitting_value.(['m' num2str(t_m)]).target_species_name) );
    elseif all( size(fitting_value.(['m' num2str(t_m)]).target_species_value_scale) ~= size(fitting_value.(['m' num2str(t_m)]).target_species_value) )
        error(['??? The specified fitting_value.m', num2str(t_m), '.target_species_value_scale is incorrect!']);
    end
    if any(fitting_value.(['m' num2str(t_m)]).target_species_value_scale(:) <= 0)
        fitting_value.(['m' num2str(t_m)]).target_species_value_scale( fitting_value.(['m' num2str(t_m)]).target_species_value_scale <= 0) = 1;
        warning('MATLAB:paramAmbiguous', ['Some data in the fitting_value.m' num2str(t_m) '.target_species_value_scale <= 0. These data will be reset to 1.']);
    end
end

end

