function simData = jz_sbioEnsemModelRun( sysbio_model, variant_index, parameters_value, report_species_name, fitting_value )

if isempty(variant_index)
    if ~isempty(parameters_value)
        warning('MATLAB:paramAmbiguous', 'Since the specified variant_index is empty, parameters_value will not be used.');
    end
    [simData.simTime, simData.simValue] = selectbyname( sbiosimulate(sysbio_model), report_species_name );
    variant_index = 1;  % Used for error caculation
else
    if ~isempty(parameters_value)
        if length(variant_index) ~= 1
            variant_index = variant_index(1);
            warning('MATLAB:paramAmbiguous', ['Since parameters_value has been specified, only the variant_index(1), i.e. sysbio_model.variant(' num2str(variant_index) ' ) will be used for the caculation.']);
        end
        if length(parameters_value) ~= length( sysbio_model.variant(variant_index).content)
            error(['??? The specified parameters_value should have the same length with sysbio_model.variant(' num2str(variant_index) ').content!']);
        end
        for t_p = 1:size(parameters_value,2)
            sysbio_model.variant(variant_index).content{t_p}(4) = { parameters_value(t_p) };
        end
    end
    simData(length(variant_index),1) = struct('simTime',[],'simValue',[]);
    for t_v = 1:length(variant_index)
        [simData(t_v).simTime, simData(t_v).simValue] = selectbyname( sbiosimulate( sysbio_model, sysbio_model.variant( variant_index(t_v)) ), report_species_name );
    end
end

if ~exist('fitting_value','var') || isempty(fitting_value)
    return;
end

for t_v = 1:length(variant_index)
    if any( isnan(simData(t_v).simValue) )
        simData(t_v).simValue_resampl = inf(size( fitting_value.target_species_value ));
    else
        simData(t_v).simValue_resampl = interp1q( simData(t_v).simTime, simData(t_v).simValue, fitting_value.time_span );
    end
    simData(t_v).simErrors = ( simData(t_v).simValue_resampl - fitting_value.target_species_value ) ./ fitting_value.target_species_value_scale;
end

end
