function [ m_sbioModel, m_variants_value, variant_min_value, variant_max_value ] = jz_sbioEnsemParamModel( sbioModel, sbioModel_variant, variant_sampling_method, ensemble_run_number, variant_value )

m_sbioModel = copyobj(sbioModel);
if ~isempty(m_sbioModel.variants)
    for t_v = 1:length(m_sbioModel.variants)
        removevariant(m_sbioModel, m_sbioModel.variant(1));
    end
end

if length(sbioModel_variant) > 1
    sbioModel_variant = sbioModel_variant(1);
    warning('MATLAB:paramAmbiguous', 'sbioModel_variant contains more than one variant, only the first variant will be used.');
end

m_variant_number = length(sbioModel_variant.content);

if strcmpi(variant_sampling_method,'none')
    if isempty(variant_value)
        m_variant_model_value = zeros(1,m_variant_number);
        for t_v = 1:m_variant_number
            value = cell2mat(sbioModel_variant.content{t_v}(4));
            if isnumeric(value)
                m_variant_model_value(t_v) = value;
            else
                m_variant_model_value(t_v) = str2double(value);
            end
        end
        m_variants_value = ones(ensemble_run_number,1) * m_variant_model_value;
    elseif all(size(variant_value) == [ensemble_run_number, m_variant_number])
        m_variants_value = variant_value;
    else
        error('??? The specified variant_value is incorrect.');
    end
    variant_min_value = [];
    variant_max_value = [];
else
    if all(size(variant_value) == [2 1])
        variant_min_value = variant_value(1) * ones(1,m_variant_number);
        variant_max_value = variant_value(2) * ones(1,m_variant_number);
    elseif all(size(variant_value) == [2 m_variant_number])
        variant_min_value = variant_value(1,:);
        variant_max_value = variant_value(2,:);
    else
        error('??? The specified variant_value is incorrect.');
    end
    m_variants_value = jz_sbioEnsemParamSampl( variant_min_value, variant_max_value, ensemble_run_number );
end

if any(m_variants_value(:) <= 0)
    warning('MATLAB:paramAmbiguous','Some parameters value <= 0.');
end

for t_n = 1:ensemble_run_number
    addvariant( m_sbioModel, sbiovariant(strcat('jz_sbiomodel_var', num2str(t_n)), sbioModel_variant.content) );
    for t_v = 1:m_variant_number
        m_sbioModel.variant(t_n).content{t_v}(4) = { m_variants_value(t_n,t_v) };
    end
end

end
