function s = jz_sbioEnsemParamSampl(xmin, xmax, n, quasi_rand_stream )

nvar = length(xmin);
if (nvar ~= length(xmax))
    error('??? The dimension of xmin and xmax should be equal.');
end
if ~all((xmax - xmin) > 0)
    error('??? The value of xmin should be less than xmax.');
end
if any(xmin <= 0)
    warning('MATLAB:paramAmbiguous', 'Some data in xmin <= 0. These data will be reset to 1e-50.');
    xmin(xmin <= 0) = 1e-50;
end

if exist('quasi_rand_stream','var')
    if size(quasi_rand_stream.PointSet,2) == nvar
        m_StandUniDistri = qrand( quasi_rand_stream, n );
    else
        error('??? The dimension of xmin (xmax) and quasi_rand_stream should be equal.');
    end
else
    m_StandUniDistri = net( scramble(haltonset(nvar,'Skip',1e3,'Leap',1e2),'RR2'), n );
end

s = zeros(n, nvar);
distribution_index = (xmax ./ xmin) <= 10;
for t_n = 1:nvar
    if distribution_index(t_n)
        delta = xmax(t_n) - xmin(t_n);
        s(:,t_n) = xmin(t_n) + delta .* m_StandUniDistri(:,t_n);
    else
        delta = log(xmax(t_n)) - log(xmin(t_n));
        s(:,t_n) = exp(log(xmin(t_n)) + delta .* m_StandUniDistri(:,t_n));
    end
end

end
